# python-MC6470
A python library for accessing MC6470 9-axis accelerometer from mCube via python-smbus using the I2C interface.

Default settings are suitable for Raspberry Pi 2 and 3 and was successfully tested.

# Usage
Consult the [data sheet](https://mcubemems.com/wp-content/uploads/2016/03/MC6470-Preliminary-Datasheet-APS-048-0033v1.5.pdf) and see demo.py to understand how to use this library.

Please send pull requests for improvements and bug fixes!

# Develop
Run make help to find out about the available development commands.

# License
Python files in this repository are released under the MIT license.
